@@ -1,12 +1,17 @@
 # -*- coding: utf-8 -*-
 
+from __future__ import absolute_import
+
 import collections
 import os
-from builtins import object
 from contextlib import contextmanager
 
-from .proto.client.pfs.pfs_pb2 import *
-from .proto.client.pfs.pfs_pb2_grpc import *
+import six
+
+from python_pachyderm.client.pfs.pfs_pb2 import *
+from python_pachyderm.client.pfs.pfs_pb2_grpc import *
+from python_pachyderm.util import commit_from, get_address
+
 
 BUFFER_SIZE = 3 * 1024 * 1024  # 3MB TODO: Base this on some grpc value
 
@@ -15,36 +20,9 @@ class ExtractValueIterator(object):
     def __init__(self, r):
         self._iter = r
 
-    def __next__(self):
-        return next(self._iter).value
-
     def __iter__(self):
-        return self
-
-
-def _commit_from(src, allow_just_repo=False):
-    if src.__class__.__name__ == "Commit":
-        return src
-    elif type(src) in (tuple, list) and len(src) == 2:
-        return Commit(repo=Repo(name=src[0]), id=src[1])
-    elif type(src) is str:
-        repo_name, commit_id = src.split('/', 1)
-        return Commit(repo=Repo(name=repo_name), id=commit_id)
-    if not allow_just_repo:
-        raise ValueError(
-            "Commit should either be a sequence of [repo, commit_id] or a string in the form 'repo/branch/commit_id")
-    return Commit(repo=Repo(name=src))
-
-
-def _make_list(x):
-    # if `x` is not iterable, put it in a list
-    if isinstance(x, (str, bytes)) or not isinstance(x, collections.Iterable):
-        x = [x]
-    return x
-
-
-def _is_iterator(x):
-    return hasattr(x, 'next') or hasattr(x, '__next__')
+        for item in self._iter:
+            yield item.value
 
 
 class PfsClient(object):
@@ -55,12 +33,8 @@ class PfsClient(object):
         :param port: The port to connect to. Default is 30650
         """
         # If a host or port is not specified, then try to set using environment variables or use the defaults.
-        if host is None:
-            host = os.environ.get('PACHD_SERVICE_HOST', 'localhost')
-        if port is None:
-            port = os.environ.get('PACHD_SERVICE_PORT_API_GRPC_PORT', '30650')
-
-        self.channel = grpc.insecure_channel('{}:{}'.format(host, port))
+        address = get_address(host, port)
+        self.channel = grpc.insecure_channel(address)
         self.stub = APIStub(self.channel)
 
     def create_repo(self, repo_name, description=None):
@@ -82,7 +56,7 @@ class PfsClient(object):
         """
         return self.stub.InspectRepo(InspectRepoRequest(repo=Repo(name=repo_name)))
 
-    def list_repo(self, provenance=tuple()):
+    def list_repo(self):
         """
         Returns info about all Repos.
 
@@ -90,7 +64,7 @@ class PfsClient(object):
         the specified repos as provenance will be returned.
         :return: A list of RepoInfo objects
         """
-        x = self.stub.ListRepo(ListRepoRequest(provenance=[Repo(name=p) for p in provenance]))
+        x = self.stub.ListRepo(ListRepoRequest())
         if hasattr(x, 'repo_info'):
             return x.repo_info
         return []
@@ -148,7 +122,7 @@ class PfsClient(object):
         attempts to write to it with PutFile will error.
         :param commit: A tuple or string representing the commit
         """
-        self.stub.FinishCommit(FinishCommitRequest(commit=_commit_from(commit)))
+        self.stub.FinishCommit(FinishCommitRequest(commit=commit_from(commit)))
 
     @contextmanager
     def commit(self, repo_name, branch=None, parent=None):
@@ -171,7 +145,7 @@ class PfsClient(object):
         :param commit: A tuple or string representing the commit
         :return: CommitInfo object
         """
-        return self.stub.InspectCommit(InspectCommitRequest(commit=_commit_from(commit)))
+        return self.stub.InspectCommit(InspectCommitRequest(commit=commit_from(commit)))
 
     def provenances_for_repo(self, repo_name):
         provenances = {}
@@ -186,7 +160,7 @@ class PfsClient(object):
     def list_commit(self, repo_name, to_commit=None, from_commit=None, number=0):
         """
         Lists commits.
-         
+
         :param repo_name: If only `repo_name` is given, all commits in the repo are returned.
         :param to_commit: optional. only the ancestors of `to`, including `to` itself,
                         are considered.
@@ -198,9 +172,9 @@ class PfsClient(object):
         """
         req = ListCommitRequest(repo=Repo(name=repo_name), number=number)
         if to_commit is not None:
-            req.to.CopyFrom(_commit_from(to_commit))
+            req.to.CopyFrom(commit_from(to_commit))
         if from_commit is not None:
-            getattr(req, 'from').CopyFrom(_commit_from(from_commit))
+            getattr(req, 'from').CopyFrom(commit_from(from_commit))
         x = self.stub.ListCommit(req)
         if hasattr(x, 'commit_info'):
             return x.commit_info
@@ -212,7 +186,7 @@ class PfsClient(object):
         Note it is currently not implemented.
         :param commit: A tuple or string representing the commit
         """
-        self.stub.DeleteCommit(DeleteCommitRequest(commit=_commit_from(commit)))
+        self.stub.DeleteCommit(DeleteCommitRequest(commit=commit_from(commit)))
 
     def flush_commit(self, commits, repos=tuple()):
         """
@@ -230,7 +204,7 @@ class PfsClient(object):
                     will be considered, otherwise all repos are considered.
         :return: An iterator of CommitInfo objects
         """
-        return self.stub.FlushCommit(FlushCommitRequest(commit=[_commit_from(c) for c in commits],
+        return self.stub.FlushCommit(FlushCommitRequest(commit=[commit_from(c) for c in commits],
                                                         to_repo=[Repo(name=r) for r in repos]))
 
     def subscribe_commit(self, repo_name, branch, from_commit_id=None):
@@ -239,7 +213,7 @@ class PfsClient(object):
         they come in.
 
         :param repo_name: Name of the repo
-        :param branch: Branch to subscribe to 
+        :param branch: Branch to subscribe to
         :param from_commit_id: Optional. only commits created since this commit are returned
 
         :return: Iterator of Commit objects
@@ -264,10 +238,10 @@ class PfsClient(object):
     def set_branch(self, commit, branch_name):
         """
         sets a commit and its ancestors as a branch
-        :param commit: A tuple or string representing the commit 
+        :param commit: A tuple or string representing the commit
         :param branch_name: The name for the branch to set
         """
-        self.stub.SetBranch(SetBranchRequest(commit=_commit_from(commit),
+        self.stub.SetBranch(SetBranchRequest(commit=commit_from(commit),
                                              branch=branch_name))
 
     def delete_branch(self, repo_name, branch_name):
@@ -275,8 +249,8 @@ class PfsClient(object):
         deletes a branch, but leaves the commits themselves intact.
         In other words, those commits can still be accessed via commit IDs and
         other branches they happen to be on.
-        :param repo_name: The name of the repo 
-        :param branch_name: The name of the branch to delete 
+        :param repo_name: The name of the repo
+        :param branch_name: The name of the branch to delete
         """
         self.stub.DeleteBranch(DeleteBranchRequest(repo=Repo(name=repo_name),
                                                    branch=branch_name))
@@ -285,51 +259,48 @@ class PfsClient(object):
                        target_file_datums=0, target_file_bytes=0):
         """
         Uploads a binary bytes array as file(s) in a certain path
-        :param commit: A tuple or string representing the commit 
+        :param commit: A tuple or string representing the commit
         :param path: Path in the repo the file(s) will be written to
-        :param value: The data bytes array, or an iterator returning chunked byte arrays 
+        :param value: The data bytes array, or an iterator returning chunked byte arrays
         :param delimiter: Optional. causes data to be broken up into separate files with `path`
                 as a prefix.
         :param target_file_datums: Optional. specifies the target number of datums in each written
                 file it may be lower if data does not split evenly, but will never be
                 higher, unless the value is 0.
         :param target_file_bytes: specifies the target number of bytes in each written
-                file, files may have more or fewer bytes than the target. 
+                file, files may have more or fewer bytes than the target.
         """
 
-        if _is_iterator(value):
-            def _wrap(v):
+        if isinstance(value, collections.Iterable) and not isinstance(value, (six.string_types, six.binary_type)):
+            def wrap(v):
                 for x in v:
-                    yield PutFileRequest(file=File(commit=_commit_from(commit), path=path),
+                    yield PutFileRequest(file=File(commit=commit_from(commit), path=path),
                                          value=x,
                                          delimiter=delimiter,
                                          target_file_datums=target_file_datums,
                                          target_file_bytes=target_file_bytes)
+        else:
+            def wrap(v):
+                for i in range(0, len(v), BUFFER_SIZE):
+                    yield PutFileRequest(file=File(commit=commit_from(commit), path=path),
+                                         value=v[i:i + BUFFER_SIZE],
+                                         delimiter=delimiter,
+                                         target_file_datums=target_file_datums,
+                                         target_file_bytes=target_file_bytes)
 
-            self.stub.PutFile(_wrap(value))
-            return
-
-        def _blocks(v):
-            for i in range(0, len(v), BUFFER_SIZE):
-                yield PutFileRequest(file=File(commit=_commit_from(commit), path=path),
-                                     value=v[i:i + BUFFER_SIZE],
-                                     delimiter=delimiter,
-                                     target_file_datums=target_file_datums,
-                                     target_file_bytes=target_file_bytes)
-
-        self.stub.PutFile(_blocks(value))
+        self.stub.PutFile(wrap(value))
 
     def put_file_url(self, commit, path, url, recursive=False):
         """
         puts a file using the content found at a URL.
         The URL is sent to the server which performs the request.
 
-        :param commit: A tuple or string representing the commit 
+        :param commit: A tuple or string representing the commit
         :param path: The path to the file
         :param url: The url to download
         :param recursive: allow for recursive scraping of some types URLs for example on s3:// urls.
         """
-        self.stub.PutFile(iter([PutFileRequest(file=File(commit=_commit_from(commit), path=path),
+        self.stub.PutFile(iter([PutFileRequest(file=File(commit=commit_from(commit), path=path),
                                                url=url,
                                                recursive=recursive)]))
 
@@ -337,18 +308,18 @@ class PfsClient(object):
         """
         returns the contents of a file at a specific Commit.
 
-        :param commit: A tuple or string representing the commit 
+        :param commit: A tuple or string representing the commit
         :param path: The path of the file
-        :param offset_bytes: Optional. specifies a number of bytes that should be skipped in the beginning of the file. 
+        :param offset_bytes: Optional. specifies a number of bytes that should be skipped in the beginning of the file.
         :param size_bytes: Optional. limits the total amount of data returned, note you will get fewer bytes
                 than size if you pass a value larger than the size of the file.
                 If size is set to 0 then all of the data will be returned.
-        :param extract_value: If True, then an ExtractValueIterator will be return, which 
+        :param extract_value: If True, then an ExtractValueIterator will be return, which
                     will iterate over the bytes of the file. If False, then the Protobuf
                     response iterator will return
         :return: An iterator over the file or an iterator over the protobuf responses
         """
-        r = self.stub.GetFile(GetFileRequest(file=File(commit=_commit_from(commit),
+        r = self.stub.GetFile(GetFileRequest(file=File(commit=commit_from(commit),
                                                        path=path),
                                              offset_bytes=offset_bytes,
                                              size_bytes=size_bytes))
@@ -360,7 +331,7 @@ class PfsClient(object):
         """
         returns the contents of a list of files at a specific Commit.
 
-        :param commit: A tuple or string representing the commit 
+        :param commit: A tuple or string representing the commit
         :param paths: A list of paths to retrieve
         :param recursive: If True, will go into each directory in the list recursively
         :return: A dictionary of file paths and data
@@ -380,11 +351,11 @@ class PfsClient(object):
     def inspect_file(self, commit, path):
         """
         returns info about a specific file.
-        :param commit: A tuple or string representing the commit 
+        :param commit: A tuple or string representing the commit
         :param path: Path to file
         :return: A FileInfo object
         """
-        return self.stub.InspectFile(InspectFileRequest(file=File(commit=_commit_from(commit),
+        return self.stub.InspectFile(InspectFileRequest(file=File(commit=commit_from(commit),
                                                                   path=path)))
 
     def list_file(self, commit, path, recursive=False):
@@ -395,7 +366,7 @@ class PfsClient(object):
         :param recursive: If True, continue listing the files for sub-directories
         :return: A list of FileInfo objects
         """
-        file_infos = self.stub.ListFile(ListFileRequest(file=File(commit=_commit_from(commit),
+        file_infos = self.stub.ListFile(ListFileRequest(file=File(commit=commit_from(commit),
                                                                   path=path))).file_info
         if recursive:
             dirs = [f for f in file_infos if f.file_type == DIR]
@@ -408,11 +379,11 @@ class PfsClient(object):
     def glob_file(self, commit, pattern):
         """
         ?
-        :param commit: 
-        :param pattern: 
+        :param commit:
+        :param pattern:
         :return: A list of FileInfo objects
         """
-        r = self.stub.GlobFile(GlobFileRequest(commit=_commit_from(commit),
+        r = self.stub.GlobFile(GlobFileRequest(commit=commit_from(commit),
                                                pattern=pattern))
         if hasattr(r, 'file_info'):
             return r.file_info
@@ -429,7 +400,7 @@ class PfsClient(object):
         :param commit: A tuple or string representing the commit
         :param path: The path to the file
         """
-        self.stub.DeleteFile(DeleteFileRequest(file=File(commit=_commit_from(commit),
+        self.stub.DeleteFile(DeleteFileRequest(file=File(commit=commit_from(commit),
                                                          path=path)))
 
     def delete_all(self):
